@@ -4,14 +4,20 @@ import re
 
 from ipyparallel.cluster.launcher import SlurmEngineSetLauncher, MPIEngineSetLauncher
 from .utils import BColor, colorize_output
+import os
 import os.path
 
 
 # check if we are using a new image that has Slurm installed, otherwise fall back to
 # regular MPI engines
 slurm_installed = os.path.isfile("/etc/slurm/cgroup.conf")
-EngineSetLauncher = SlurmEngineSetLauncher if slurm_installed else MPIEngineSetLauncher
-
+# Feature flag for testing Slurm. This will be set during instance initialization (userdata).
+# Default: `false` until the feature is stabilized.
+use_slurm_if_installed = os.environ.get("BODO_CONF_USE_SLURM", "false").lower() == "true"
+if slurm_installed and use_slurm_if_installed:
+    EngineSetLauncher = SlurmEngineSetLauncher
+else:
+    EngineSetLauncher = MPIEngineSetLauncher
 
 class BodoPlatformMPIEngineSetLauncher(EngineSetLauncher):
     def _get_error_message_from_exit_code(self, exit_code: str):
